@@ -12,6 +12,18 @@ def get_limits(ax):
 def parameter_distributions(brute, xvals=None, bw_method=None, filter_zeros=None, coefs=None, ax=None):
     """
     Plot a density distribution diagram for fitted models.
+
+    Parameters
+    ----------
+    xvals : array-like
+        The x axis for the density plots. If None, x values are calculated
+        to span the range of the coefficients +/- 5%
+    bw_method : str
+        The method to calculate the bin width of the kernel density estimator.
+        Passed to scipy.stats.gaussian_kde.
+    filter_zeros : float
+        Remove distributions that overlap with zero by more than this fraction.
+    
     """
     if ax is None:
         fig, ax = plt.subplots(1, 1)
@@ -77,15 +89,15 @@ def parameter_distributions(brute, xvals=None, bw_method=None, filter_zeros=None
         else:
             pdf = []
         
-        ax.plot(xvals, pdf, label=brute.vardict[c], color=brute.varcolors[c], alpha=line_alpha, zorder=zorder)
-        ax.fill_between(xvals, pdf, color=brute.varcolors[c], alpha=face_alpha, zorder=zorder)
+        ax.plot(xvals, pdf, label=brute.vardict[c], alpha=line_alpha, zorder=zorder)
+        ax.fill_between(xvals, pdf, alpha=face_alpha, zorder=zorder)
     
     # ax.set_ylim(0, ax.get_ylim()[1])
     ax.axvline(0, ls='dashed', c=(0,0,0,0.3), zorder=-1)
     ax.set_xlabel('Covariate Influence')
     ax.set_ylabel('Probability Density')
 
-def observed_vs_predicted(brute, model_ind=None, ax=None, **kwargs):
+def observed_vs_predicted(brute, ax, model_ind):
     """
     Plot observed vs. predicted data.
     """
@@ -107,17 +119,8 @@ def observed_vs_predicted(brute, model_ind=None, ax=None, **kwargs):
     else:
         xerr = None
 
-    if model_ind is None:
-        ax.scatter(y, brute.pred_means, **kwargs)
-        ax.errorbar(y, brute.pred_means, xerr=xerr, yerr=brute.pred_stds, lw=0, elinewidth=1)
-    else:
-        print(model_ind)
-        ax.scatter(y, brute.pred_all[model_ind], **kwargs)
-        ax.errorbar(y, brute.pred_all[model_ind], xerr=xerr, lw=0, elinewidth=1)
+    ax.errorbar(y.flat, brute.pred_means, xerr=xerr, yerr=brute.pred_stds, marker='o', markersize=3, lw=0, elinewidth=1)
 
     ax.set_xlabel('Measured')
-    if model_ind is None:
-        ax.set_ylabel('Predicted (all models)')
-    else:
-        ax.set_ylabel(f'Predicted (model {model_ind:.0f})')
+    ax.set_ylabel('Predicted')
     ax.set_aspect(1)
